You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by ac...@apache.org on 2018/09/06 13:10:33 UTC

[camel] 02/05: CAMEL-12784 - Create a Camel-google-calendar-stream component

This is an automated email from the ASF dual-hosted git repository.

acosentino pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git

commit addee9c5495574a979d7b066ab3ff3504b2be9c8
Author: Andrea Cosentino <an...@gmail.com>
AuthorDate: Thu Sep 6 14:17:58 2018 +0200

    CAMEL-12784 - Create a Camel-google-calendar-stream component
---
 .../calendar/stream/GoogleCalendarStreamConfiguration.java     |  6 +++---
 .../google/calendar/stream/GoogleCalendarStreamEndpoint.java   |  5 ++---
 .../springboot/GoogleCalendarStreamComponentConfiguration.java | 10 ++++++----
 3 files changed, 11 insertions(+), 10 deletions(-)

diff --git a/components/camel-google-calendar/src/main/java/org/apache/camel/component/google/calendar/stream/GoogleCalendarStreamConfiguration.java b/components/camel-google-calendar/src/main/java/org/apache/camel/component/google/calendar/stream/GoogleCalendarStreamConfiguration.java
index 25396fb..a7d654a 100644
--- a/components/camel-google-calendar/src/main/java/org/apache/camel/component/google/calendar/stream/GoogleCalendarStreamConfiguration.java
+++ b/components/camel-google-calendar/src/main/java/org/apache/camel/component/google/calendar/stream/GoogleCalendarStreamConfiguration.java
@@ -112,7 +112,7 @@ public class GoogleCalendarStreamConfiguration implements Cloneable {
     }
 
     /**
-     * Google mail application name. Example would be "camel-google-mail/1.0"
+     * Google Calendar application name. Example would be "camel-google-calendar/1.0"
      */
     public void setApplicationName(String applicationName) {
         this.applicationName = applicationName;
@@ -124,7 +124,7 @@ public class GoogleCalendarStreamConfiguration implements Cloneable {
 
     /**
      * Specifies the level of permissions you want a mail application to have to
-     * a user account. See https://developers.google.com/gmail/api/auth/scopes
+     * a user account. See https://developers.google.com/calendar/api/auth/scopes
      * for more info.
      */
     public void setScopes(List<String> scopes) {
@@ -147,7 +147,7 @@ public class GoogleCalendarStreamConfiguration implements Cloneable {
     }
 
     /**
-     * The query to execute on gmail box
+     * The query to execute on calendar
      */
     public void setQuery(String query) {
         this.query = query;
diff --git a/platforms/spring-boot/components-starter/camel-google-calendar-starter/src/main/java/org/apache/camel/component/google/calendar/stream/springboot/GoogleCalendarStreamComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-google-calendar-starter/src/main/java/org/apache/camel/component/google/calendar/stream/springboot/GoogleCalendarStreamComponentConfiguration.java
index e1ed7ac..598fc40 100644
--- a/platforms/spring-boot/components-starter/camel-google-calendar-starter/src/main/java/org/apache/camel/component/google/calendar/stream/springboot/GoogleCalendarStreamComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-google-calendar-starter/src/main/java/org/apache/camel/component/google/calendar/stream/springboot/GoogleCalendarStreamComponentConfiguration.java
@@ -22,7 +22,8 @@ import org.apache.camel.spring.boot.ComponentConfigurationPropertiesCommon;
 import org.springframework.boot.context.properties.ConfigurationProperties;
 
 /**
- * The google-mail component provides access to Google Mail.
+ * The google-calendar component provides access to Google Calendar in a
+ * streaming mod.
  * 
  * Generated by camel-package-maven-plugin - do not edit this file!
  */
@@ -102,13 +103,14 @@ public class GoogleCalendarStreamComponentConfiguration
          */
         private String refreshToken;
         /**
-         * Google mail application name. Example would be camel-google-mail/1.0
+         * Google Calendar application name. Example would be
+         * camel-google-calendar/1.0
          */
         private String applicationName;
         /**
          * Specifies the level of permissions you want a mail application to
          * have to a user account. See
-         * https://developers.google.com/gmail/api/auth/scopes for more info.
+         * https://developers.google.com/calendar/api/auth/scopes for more info.
          */
         private List scopes;
         /**
@@ -116,7 +118,7 @@ public class GoogleCalendarStreamComponentConfiguration
          */
         private String index;
         /**
-         * The query to execute on gmail box
+         * The query to execute on calendar
          */
         private String query;
         /**
diff --git a/components/camel-google-calendar/src/main/java/org/apache/camel/component/google/calendar/stream/GoogleCalendarStreamEndpoint.java b/components/camel-google-calendar/src/main/java/org/apache/camel/component/google/calendar/stream/GoogleCalendarStreamEndpoint.java
index 952c476..5331601 100644
--- a/components/camel-google-calendar/src/main/java/org/apache/camel/component/google/calendar/stream/GoogleCalendarStreamEndpoint.java
+++ b/components/camel-google-calendar/src/main/java/org/apache/camel/component/google/calendar/stream/GoogleCalendarStreamEndpoint.java
@@ -33,7 +33,7 @@ import org.apache.camel.spi.UriEndpoint;
 import org.apache.camel.spi.UriParam;
 
 /**
  * The google-mail component provides access to Google Mail.
  */
 @UriEndpoint(firstVersion = "2.23.0", 
              scheme = "google-calendar-stream", 
@@ -54,7 +54,7 @@ public class GoogleCalendarStreamEndpoint extends ScheduledPollEndpoint {
 
     @Override
     public Producer createProducer() throws Exception {
-        throw new UnsupportedOperationException("The camel google mail stream component doesn't support producer");
+        throw new UnsupportedOperationException("The camel google calendar stream component doesn't support producer");
     }
 
     @Override
@@ -90,7 +90,6 @@ public class GoogleCalendarStreamEndpoint extends ScheduledPollEndpoint {
         Exchange exchange = super.createExchange();
         Message message = exchange.getIn();
         message.setBody(event);
-        System.err.println("Ciao " + message.getBody().toString());
         return exchange;
     }
 }
@@ -33,7 +33,7 @@ import org.apache.camel.spi.UriEndpoint;
 
 /**
- * The google-mail component provides access to Google Mail.
+ * The google-calendar component provides access to Google Calendar in a streaming mod.
  */
 @UriEndpoint(firstVersion = "2.23.0", 